"""
    This file was generated by flowtool-versioning.
    Homepage: https://github.com/isnok/py-flowlib
"""

VERSION_INFO = {'vcs_info': {'commit': 'b9ef1dc838bc82ac4c2423718c15c7c28029bf64',
              'dirt': '',
              'latest_tag': 'flowtool-releasing-0.7.13',
              'latest_tag_commit': 'b9ef1dc838bc82ac4c2423718c15c7c28029bf64',
              'latest_tag_version': '0.7.13',
              'prefix': 'flowtool-releasing-',
              'prefix_tag_distances': {'flowtool-releasing-0.7.10': 96,
                                       'flowtool-releasing-0.7.11': 60,
                                       'flowtool-releasing-0.7.12': 40,
                                       'flowtool-releasing-0.7.13': 0,
                                       'flowtool-releasing-0.7.5': 144,
                                       'flowtool-releasing-0.7.6': 143,
                                       'flowtool-releasing-0.7.7': 139,
                                       'flowtool-releasing-0.7.8': 127,
                                       'flowtool-releasing-0.7.9': 107},
              'tag_version': {'normalized': '0.7.13',
                              'release': (0, 7, 13),
                              'version': '0.7.13'}},
 'version': '0.7.13'}

def get_version():
    global VERSION_INFO
    return VERSION_INFO.get('version', '$Format:%d %H$')
